==> nacos-client-2.3.0-sources.jar: com/alibaba/nacos/shaded/io/grpc/util/ForwardingLoadBalancerHelper.java <==
/*
 * Copyright 2018 The gRPC Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.alibaba.nacos.shaded.io.grpc.util;

import com.alibaba.nacos.shaded.com.google.common.base.MoreObjects;
import com.alibaba.nacos.shaded.io.grpc.ChannelCredentials;
import com.alibaba.nacos.shaded.io.grpc.ChannelLogger;
import com.alibaba.nacos.shaded.io.grpc.ConnectivityState;
import com.alibaba.nacos.shaded.io.grpc.EquivalentAddressGroup;
import com.alibaba.nacos.shaded.io.grpc.ExperimentalApi;
import com.alibaba.nacos.shaded.io.grpc.LoadBalancer;
import com.alibaba.nacos.shaded.io.grpc.LoadBalancer.CreateSubchannelArgs;
import com.alibaba.nacos.shaded.io.grpc.LoadBalancer.Subchannel;
import com.alibaba.nacos.shaded.io.grpc.LoadBalancer.SubchannelPicker;
import com.alibaba.nacos.shaded.io.grpc.ManagedChannel;
import com.alibaba.nacos.shaded.io.grpc.ManagedChannelBuilder;
import com.alibaba.nacos.shaded.io.grpc.NameResolver;
import com.alibaba.nacos.shaded.io.grpc.NameResolverRegistry;
import com.alibaba.nacos.shaded.io.grpc.SynchronizationContext;
import java.util.List;
import java.util.concurrent.ScheduledExecutorService;

@ExperimentalApi("https://github.com/grpc/grpc-java/issues/1771")
public abstract class ForwardingLoadBalancerHelper extends LoadBalancer.Helper {
  /**
   * Returns the underlying helper.
   */
  protected abstract LoadBalancer.Helper delegate();

  @Override
  public Subchannel createSubchannel(CreateSubchannelArgs args) {
    return delegate().createSubchannel(args);
  }

  @Override
  public  ManagedChannel createOobChannel(EquivalentAddressGroup eag, String authority) {
    return delegate().createOobChannel(eag, authority);
  }

  @Override
  public  ManagedChannel createOobChannel(List<EquivalentAddressGroup> eag, String authority) {
    return delegate().createOobChannel(eag, authority);
  }

  @Override
  public void updateOobChannelAddresses(ManagedChannel channel, EquivalentAddressGroup eag) {
    delegate().updateOobChannelAddresses(channel, eag);
  }

  @Override
  public void updateOobChannelAddresses(ManagedChannel channel, List<EquivalentAddressGroup> eag) {
    delegate().updateOobChannelAddresses(channel, eag);
  }

  @Deprecated
  @Override
  public ManagedChannelBuilder<?> createResolvingOobChannelBuilder(String target) {
    return delegate().createResolvingOobChannelBuilder(target);
  }

  @Override
  public ManagedChannelBuilder<?> createResolvingOobChannelBuilder(
      String target, ChannelCredentials creds) {
    return delegate().createResolvingOobChannelBuilder(target, creds);
  }

  @Override
  public ManagedChannel createResolvingOobChannel(String target) {
    return delegate().createResolvingOobChannel(target);
  }

  @Override
  public void updateBalancingState(
      ConnectivityState newState, SubchannelPicker newPicker) {
    delegate().updateBalancingState(newState, newPicker);
  }

  @Override
  public void refreshNameResolution() {
    delegate().refreshNameResolution();
  }

  @Override
  @Deprecated
  public void ignoreRefreshNameResolutionCheck() {
    delegate().ignoreRefreshNameResolutionCheck();
  }

  @Override
  public String getAuthority() {
    return delegate().getAuthority();
  }

  @Override
  public ChannelCredentials getChannelCredentials() {
    return delegate().getChannelCredentials();
  }

  @Override
  public ChannelCredentials getUnsafeChannelCredentials() {
    return delegate().getUnsafeChannelCredentials();
  }

  @Override
  public SynchronizationContext getSynchronizationContext() {
    return delegate().getSynchronizationContext();
  }

  @Override
  public ScheduledExecutorService getScheduledExecutorService() {
    return delegate().getScheduledExecutorService();
  }

  @Override
  public ChannelLogger getChannelLogger() {
    return delegate().getChannelLogger();
  }

  @Override
  public NameResolver.Args getNameResolverArgs() {
    return delegate().getNameResolverArgs();
  }

  @Override
  public NameResolverRegistry getNameResolverRegistry() {
    return delegate().getNameResolverRegistry();
  }

  @Override
  public String toString() {
    return MoreObjects.toStringHelper(this).add("delegate", delegate()).toString();
  }
}

==> nacos-client-3.0.2-sources.jar: com/alibaba/nacos/shaded/io/grpc/util/ForwardingLoadBalancerHelper.java <==
/*
 * Copyright 2018 The gRPC Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.alibaba.nacos.shaded.io.grpc.util;

import com.alibaba.nacos.shaded.com.google.common.base.MoreObjects;
import com.alibaba.nacos.shaded.io.grpc.ChannelCredentials;
import com.alibaba.nacos.shaded.io.grpc.ChannelLogger;
import com.alibaba.nacos.shaded.io.grpc.ConnectivityState;
import com.alibaba.nacos.shaded.io.grpc.EquivalentAddressGroup;
import com.alibaba.nacos.shaded.io.grpc.ExperimentalApi;
import com.alibaba.nacos.shaded.io.grpc.LoadBalancer;
import com.alibaba.nacos.shaded.io.grpc.LoadBalancer.CreateSubchannelArgs;
import com.alibaba.nacos.shaded.io.grpc.LoadBalancer.Subchannel;
import com.alibaba.nacos.shaded.io.grpc.LoadBalancer.SubchannelPicker;
import com.alibaba.nacos.shaded.io.grpc.ManagedChannel;
import com.alibaba.nacos.shaded.io.grpc.ManagedChannelBuilder;
import com.alibaba.nacos.shaded.io.grpc.MetricRecorder;
import com.alibaba.nacos.shaded.io.grpc.NameResolver;
import com.alibaba.nacos.shaded.io.grpc.NameResolverRegistry;
import com.alibaba.nacos.shaded.io.grpc.SynchronizationContext;
import java.util.List;
import java.util.concurrent.ScheduledExecutorService;

@ExperimentalApi("https://github.com/grpc/grpc-java/issues/1771")
public abstract class ForwardingLoadBalancerHelper extends LoadBalancer.Helper {
  /**
   * Returns the underlying helper.
   */
  protected abstract LoadBalancer.Helper delegate();

  @Override
  public Subchannel createSubchannel(CreateSubchannelArgs args) {
    return delegate().createSubchannel(args);
  }

  @Override
  public  ManagedChannel createOobChannel(EquivalentAddressGroup eag, String authority) {
    return delegate().createOobChannel(eag, authority);
  }

  @Override
  public  ManagedChannel createOobChannel(List<EquivalentAddressGroup> eag, String authority) {
    return delegate().createOobChannel(eag, authority);
  }

  @Override
  public void updateOobChannelAddresses(ManagedChannel channel, EquivalentAddressGroup eag) {
    delegate().updateOobChannelAddresses(channel, eag);
  }

  @Override
  public void updateOobChannelAddresses(ManagedChannel channel, List<EquivalentAddressGroup> eag) {
    delegate().updateOobChannelAddresses(channel, eag);
  }

  @Deprecated
  @Override
  public ManagedChannelBuilder<?> createResolvingOobChannelBuilder(String target) {
    return delegate().createResolvingOobChannelBuilder(target);
  }

  @Override
  public ManagedChannelBuilder<?> createResolvingOobChannelBuilder(
      String target, ChannelCredentials creds) {
    return delegate().createResolvingOobChannelBuilder(target, creds);
  }

  @Override
  public ManagedChannel createResolvingOobChannel(String target) {
    return delegate().createResolvingOobChannel(target);
  }

  @Override
  public void updateBalancingState(
      ConnectivityState newState, SubchannelPicker newPicker) {
    delegate().updateBalancingState(newState, newPicker);
  }

  @Override
  public void refreshNameResolution() {
    delegate().refreshNameResolution();
  }

  @Override
  @Deprecated
  public void ignoreRefreshNameResolutionCheck() {
    delegate().ignoreRefreshNameResolutionCheck();
  }

  @Override
  public String getAuthority() {
    return delegate().getAuthority();
  }

  @Override
  public String getChannelTarget() {
    return delegate().getChannelTarget();
  }

  @Override
  public ChannelCredentials getChannelCredentials() {
    return delegate().getChannelCredentials();
  }

  @Override
  public ChannelCredentials getUnsafeChannelCredentials() {
    return delegate().getUnsafeChannelCredentials();
  }

  @Override
  public SynchronizationContext getSynchronizationContext() {
    return delegate().getSynchronizationContext();
  }

  @Override
  public ScheduledExecutorService getScheduledExecutorService() {
    return delegate().getScheduledExecutorService();
  }

  @Override
  public ChannelLogger getChannelLogger() {
    return delegate().getChannelLogger();
  }

  @Override
  public NameResolver.Args getNameResolverArgs() {
    return delegate().getNameResolverArgs();
  }

  @Override
  public NameResolverRegistry getNameResolverRegistry() {
    return delegate().getNameResolverRegistry();
  }

  @Override
  public MetricRecorder getMetricRecorder() {
    return delegate().getMetricRecorder();
  }

  @Override
  public String toString() {
    return MoreObjects.toStringHelper(this).add("delegate", delegate()).toString();
  }
}
